@@ -5,7 +5,7 @@ import os.path
 import random
 import string
 import sys
-from typing import AnyStr, Optional
+from typing import Optional
 
 from rcmt import action, matcher, source
 from rcmt.fs import FileProxy
@@ -24,6 +24,8 @@ class Run:
     :param branch_name: Name of the branch in git. Defaults to ``branch_prefix`` +
                         ``name``.
     :param commit_msg: Message to use when committing changes via git.
+    :delete_branch_after_merge: If ``True``, rcmt will delete the branch after it has
+                                been merged.
     :param merge_once: If ``True``, rcmt does not create another pull request if it
                        created a pull request for the same branch before and that pull
                        request has been merged.
@@ -59,6 +61,7 @@ class Run:
         auto_merge_after: Optional[datetime.timedelta] = None,
         branch_name: str = "",
         commit_msg: str = "Applied actions",
+        delete_branch_after_merge: bool = True,
         merge_once: bool = False,
         pr_body: str = "",
         pr_title: str = "",
@@ -67,6 +70,7 @@ class Run:
         self.auto_merge_after = auto_merge_after
         self.branch_name = branch_name
         self.commit_msg = commit_msg
+        self.delete_branch_after_merge = delete_branch_after_merge
         self.pr_body = pr_body
         self.pr_title = pr_title
         self.merge_once = merge_once
